pub struct CreateServerSubuserOptions<'a> {
pub server: &'a Server,
pub email: CompactString,
pub permissions: Vec<CompactString>,
pub ignored_files: Vec<CompactString>,
}Fields
server: &'a Serveremail: CompactStringpermissions: Vec<CompactString>ignored_files: Vec<CompactString>Trait Implementations
Sourceimpl<'a> Validate for CreateServerSubuserOptions<'a>
impl<'a> Validate for CreateServerSubuserOptions<'a>
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl<'a> Freeze for CreateServerSubuserOptions<'a>
impl<'a> RefUnwindSafe for CreateServerSubuserOptions<'a>
impl<'a> Send for CreateServerSubuserOptions<'a>
impl<'a> Sync for CreateServerSubuserOptions<'a>
impl<'a> Unpin for CreateServerSubuserOptions<'a>
impl<'a> UnwindSafe for CreateServerSubuserOptions<'a>