pub struct UpdateServerSubuserOptions {
pub permissions: Option<Vec<CompactString>>,
pub ignored_files: Option<Vec<CompactString>>,
}Fields
permissions: Option<Vec<CompactString>>ignored_files: Option<Vec<CompactString>>Trait Implementations
Sourceimpl ComposeSchema for UpdateServerSubuserOptions
impl ComposeSchema for UpdateServerSubuserOptions
Sourceimpl Default for UpdateServerSubuserOptions
impl Default for UpdateServerSubuserOptions
Sourcefn default() -> UpdateServerSubuserOptions
fn default() -> UpdateServerSubuserOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateServerSubuserOptions
impl<'de> Deserialize<'de> for UpdateServerSubuserOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for UpdateServerSubuserOptions
impl ToSchema for UpdateServerSubuserOptions
Sourceimpl Validate for UpdateServerSubuserOptions
impl Validate for UpdateServerSubuserOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateServerSubuserOptions
impl RefUnwindSafe for UpdateServerSubuserOptions
impl Send for UpdateServerSubuserOptions
impl Sync for UpdateServerSubuserOptions
impl Unpin for UpdateServerSubuserOptions
impl UnwindSafe for UpdateServerSubuserOptions